
# Change Log

---

When using Github, consider using [Github Release Workflow](https://docs.github.com/en/repositories/releasing-projects-on-github/automatically-generated-release-notes) instead of this changelog

---

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/)
and this project adheres to [Semantic Versioning](http://semver.org/).

## [Unreleased] - yyyy-mm-dd

Initial revision with basic functionality

### Added

### Changed

### Fixed

### Known Issues
